#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.15
visibility:           public
id:                   haskell-src-meta-0.8.15-16iHADPnL33DxD7REP4eBQ
key:                  haskell-src-meta-0.8.15-16iHADPnL33DxD7REP4eBQ
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  a50fe8b53846039a9a47fed92ae81e88
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-meta-0.8.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.15-16iHADPnL33DxD7REP4eBQ
depends:
    base-4.18.2.1 haskell-src-exts-1.23.1-G9L5maLm0JiGBv0lh0bYw0
    pretty-1.1.3.6 syb-0.7.3-11K0viXu9hkJBGIPMEQMvn
    template-haskell-2.20.0.0 th-orphans-0.13.17-IKmCPx195yNHtYfoAZlJxQ

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

